/* QuestCore Item Generator
 *
 * Version 1.2
 * 2/16/2021
 *
 * Function for generating monster scripts
 *
 * monster.c
 */

#include <stdio.h>
#include <string.h>
#include "defaults.h"
#include "color.h"

void mkmonster(void)
{
	typedef struct
	{
		char name[32];
		char varname[24];
		char shortname[24];
		char desc[128];
		char spawn_msg[64];
		char death_msg[64];
		char strength[8];
		char dexterity[8];
		char intelligence[8];
		char health[8];
		char combat[8];
		char exp[8];
		char gold[8];
		char hostility[4];
		char nat_def[4];
		char wanders[4];
		char picks_up[4];
		char edible[4];
		char immune_magic[4];
		char eat_heal[8];
		char rot_time[8];
		char respawn[8];
		char weapons[128];
	} MONSTER_T;

	char m_outfile[64];

	printf("%sFile (default: %s): %s", GREEN, DEFAULT_MONSTER_OUTPUT_FILE, RESET);
	fgets(m_outfile, 64, stdin);
	m_outfile[strcspn(m_outfile, "\n")] = 0;

	if (strlen(m_outfile) == 0) {
		strcpy(m_outfile, DEFAULT_MONSTER_OUTPUT_FILE);
	}

	MONSTER_T Monster;
	FILE *fptr;
	fptr = fopen(m_outfile, "a");

	printf("Creating new monster...\nWriting to file %s\n\n", m_outfile);

	printf("%sMonster Name: %s", GREEN, RESET);
	fgets(Monster.name, 32, stdin);
	fprintf(fptr, "@create $monster named %s", Monster.name);

	printf("%sGlobal Variable Name for #0: %s", GREEN, RESET);
	fgets(Monster.varname, 24, stdin);
	Monster.varname[strcspn(Monster.varname, "\n")] = 0;

	char sn[4] = {Monster.name[0], Monster.name[1], Monster.name[2], '\0'};
	strcpy(Monster.shortname, sn);

	printf("%sDescription: %s", GREEN, RESET);
	fgets(Monster.desc, 128, stdin);
	fprintf(fptr, "@desc %s as %s", Monster.shortname, Monster.desc);

	printf("%sSpawn Message: %s", GREEN, RESET);
	fgets(Monster.spawn_msg, 128, stdin);
	Monster.spawn_msg[strcspn(Monster.spawn_msg, "\n")] = 0;
	fprintf(fptr, "@birth_msg %s is \"%s\"\n", Monster.shortname, Monster.spawn_msg);

	printf("%sDeath Message: %s", GREEN, RESET);
	fgets(Monster.death_msg, 128, stdin);
	Monster.death_msg[strcspn(Monster.death_msg, "\n")] = 0;
	fprintf(fptr, "@death_msg %s is \"%s\"\n", Monster.shortname, Monster.death_msg);

	printf("%sStrength: %s", GREEN, RESET);
	fgets(Monster.strength, 8, stdin);
	fprintf(fptr, "@str %s is %s", Monster.shortname, Monster.strength);

	printf("%sDexterity: %s", GREEN, RESET);
	fgets(Monster.dexterity, 8, stdin);
	fprintf(fptr, "@dex %s is %s", Monster.shortname, Monster.dexterity);

	printf("%sIntelligence: %s", GREEN, RESET);
	fgets(Monster.intelligence, 8, stdin);
	fprintf(fptr, "@int %s is %s", Monster.shortname, Monster.intelligence);

	printf("%sHealth: %s", GREEN, RESET);
	fgets(Monster.health, 8, stdin);
	fprintf(fptr, "@hea %s is %s", Monster.shortname, Monster.health);

	printf("%sCombat: %s", GREEN, RESET);
	fgets(Monster.combat, 8, stdin);
	fprintf(fptr, "@com %s is %s", Monster.shortname, Monster.combat);

	printf("%sXP: %s", GREEN, RESET);
	fgets(Monster.exp, 8, stdin);
	fprintf(fptr, "@set %s.exp to %s", Monster.shortname, Monster.exp);

	printf("%sGold (decimal): %s", GREEN, RESET);
	fgets(Monster.gold, 8, stdin);
	Monster.gold[strcspn(Monster.gold, "\n")] = 0;
	fprintf(fptr, "@set %s.startmoney to {{\"gold\", %s}}\n", Monster.shortname, Monster.gold);
	fprintf(fptr, "@set %s.money to {{\"gold\", %s}}\n", Monster.shortname, Monster.gold);

	printf("%sHostility (0 to 6): %s", GREEN, RESET);
	fgets(Monster.hostility, 4, stdin);
	fprintf(fptr, "@set %s.hostility to %s", Monster.shortname, Monster.hostility);

	printf("%sNatural Defense (0 to 2): %s", GREEN, RESET);
	fgets(Monster.nat_def, 4, stdin);
	fprintf(fptr, "@set %s.natural_def to %s", Monster.shortname, Monster.nat_def);

	printf("%sCan Wander (0 or 1): %s", GREEN, RESET);
	fgets(Monster.wanders, 4, stdin);
	fprintf(fptr, "@set %s.wander_ok to %s", Monster.shortname, Monster.wanders);

	printf("%sPicks Up Items (0 or 1): %s", GREEN, RESET);
	fgets(Monster.picks_up, 4, stdin);
	fprintf(fptr, "@set %s.greedy to %s", Monster.shortname, Monster.picks_up);

	printf("%sCan Be Eaten (0 or 1): %s", GREEN, RESET);
	fgets(Monster.edible, 4, stdin);
	fprintf(fptr, "@set %s.edible to %s", Monster.shortname, Monster.edible);

	printf("%sMagic Immunity (0 or 1): %s", GREEN, RESET);
	fgets(Monster.immune_magic, 4, stdin);
	fprintf(fptr, "@set %s.magic_immunity to %s", Monster.shortname, Monster.immune_magic);

	if (!strcmp(Monster.edible, "1\n")) {
		printf("%sHealth From Eating (decimal): %s", GREEN, RESET);
		fgets(Monster.eat_heal, 8, stdin);
	} else {
		strcpy(Monster.eat_heal, "0.0\n");
	}
	fprintf(fptr, "@set %s.eat_heal to %s", Monster.shortname, Monster.eat_heal);

	printf("%sRot Time (seconds): %s", GREEN, RESET);
	fgets(Monster.rot_time, 8, stdin);
	fprintf(fptr, "@set %s.rot_time to %s", Monster.shortname, Monster.rot_time);

	printf("%sRespawn Time (seconds): %s", GREEN, RESET);
	fgets(Monster.respawn, 8, stdin);
	fprintf(fptr, "@set %s.gestate to %s", Monster.shortname, Monster.respawn);

	printf("%sWeapons: (#obj1, #...): %s", GREEN, RESET);
	fgets(Monster.weapons, 128, stdin);
	Monster.weapons[strcspn(Monster.weapons, "\n")] = 0;
	if (!strcmp(Monster.weapons, "")) {
		fprintf(fptr, "@set %s.weapon_types to {}\n", Monster.shortname);
	} else {
		fprintf(fptr, "@set %s.weapon_types to {%s}\n", Monster.shortname, Monster.weapons);
	}

	fprintf(fptr, "@chmod %s rf\n", Monster.shortname);
	fprintf(fptr, ";add_property(#0, \"%s\", max_object(), {player, \"rc\"})\n", Monster.varname);
	fprintf(fptr, ";move($%s, $nothing)\n", Monster.varname);
	fprintf(fptr, "@kgen $%s\n", Monster.varname);

	fprintf(fptr, "\n");
	fclose(fptr);
	return;
}
